Module prelude

Module prelude 

The refining-length prelude.

Structs

LengthEqual
Checks whether the value has length equal to N.
LengthGreater
Checks whether the value has length greater than N.
LengthGreaterOrEqual
Checks whether the value has length greater than or equal to N.
LengthLess
Checks whether the value has length less than N.
LengthLessOrEqual
Checks whether the value has length less than or equal to N.
LengthModulo
Checks whether the given value has length that has modulo M when divided by D.
LengthNotEqual
Checks whether the value has length not equal to N.

Traits

HasLength
Represents types that have length defined for their values.

Type Aliases

LengthClosed
Represents [M, N] intervals.
LengthClosedOpen
Represents [M, N) intervals.
LengthDivisible
Checks whether the given value length is divisible by D.
LengthEven
Checks whether the given value length is even.
LengthNonZero
Checks whether the given value has non-zero length.
LengthOdd
Checks whether the given value length is odd.
LengthOpen
Represents (M, N) intervals.
LengthOpenClosed
Represents (M, N] intervals.
LengthZero
Checks whether the given value has zero length.