pub type LengthDivisible<const D: usize> = LengthModulo<D, ZERO>;Expand description
Checks whether the given value length is divisible by D.
Aliased Type
pub struct LengthDivisible<const D: usize> { /* private fields */ }pub type LengthDivisible<const D: usize> = LengthModulo<D, ZERO>;Checks whether the given value length is divisible by D.
pub struct LengthDivisible<const D: usize> { /* private fields */ }